package cn.com.infosec.asn1.smime;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.nist.NISTObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;

public class SMIMECapability extends ASN1Encodable {
   public static final DERObjectIdentifier preferSignedData;
   public static final DERObjectIdentifier canNotDecryptAny;
   public static final DERObjectIdentifier sMIMECapabilitiesVersions;
   public static final DERObjectIdentifier dES_CBC;
   public static final DERObjectIdentifier dES_EDE3_CBC;
   public static final DERObjectIdentifier rC2_CBC;
   public static final DERObjectIdentifier aES128_CBC;
   public static final DERObjectIdentifier aES192_CBC;
   public static final DERObjectIdentifier aES256_CBC;
   private DERObjectIdentifier capabilityID;
   private DEREncodable parameters;

   static {
      preferSignedData = PKCSObjectIdentifiers.preferSignedData;
      canNotDecryptAny = PKCSObjectIdentifiers.canNotDecryptAny;
      sMIMECapabilitiesVersions = PKCSObjectIdentifiers.sMIMECapabilitiesVersions;
      dES_CBC = new DERObjectIdentifier("1.3.14.3.2.7");
      dES_EDE3_CBC = PKCSObjectIdentifiers.des_EDE3_CBC;
      rC2_CBC = PKCSObjectIdentifiers.RC2_CBC;
      aES128_CBC = NISTObjectIdentifiers.id_aes128_CBC;
      aES192_CBC = NISTObjectIdentifiers.id_aes192_CBC;
      aES256_CBC = NISTObjectIdentifiers.id_aes256_CBC;
   }

   public SMIMECapability(ASN1Sequence seq) {
      this.capabilityID = (DERObjectIdentifier)seq.getObjectAt(0);
      if (seq.size() > 1) {
         this.parameters = (DERObject)seq.getObjectAt(1);
      }

   }

   public SMIMECapability(DERObjectIdentifier capabilityID, DEREncodable parameters) {
      this.capabilityID = capabilityID;
      this.parameters = parameters;
   }

   public static SMIMECapability getInstance(Object obj) {
      if (obj != null && !(obj instanceof SMIMECapability)) {
         if (obj instanceof ASN1Sequence) {
            return new SMIMECapability((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid SMIMECapability");
         }
      } else {
         return (SMIMECapability)obj;
      }
   }

   public DERObjectIdentifier getCapabilityID() {
      return this.capabilityID;
   }

   public DEREncodable getParameters() {
      return this.parameters;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.capabilityID);
      DEREncodable var2;
      if ((var2 = this.parameters) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
